import RichTextResolver from './richTextResolver';
import { ISbStoriesParams, ISbConfig, ISbResult, ISbStories, ISbStory, ISbStoryData, ISbStoryParams, ISbContentMangmntAPI, ISbCustomFetch } from './interfaces';
type ComponentResolverFn = {
    (...args: any): any;
};
type CachedVersions = {
    [key: string]: number;
};
type LinksType = {
    [key: string]: any;
};
type RelationsType = {
    [key: string]: any;
};
interface ISbResponseData {
    link_uuids: string[];
    links: string[];
    rel_uuids: string[];
    rels: any;
    story: ISbStoryData;
    stories: Array<ISbStoryData>;
}
declare class Storyblok {
    private client;
    private maxRetries;
    private throttle;
    private accessToken;
    private cache;
    private helpers;
    private resolveCounter;
    relations: RelationsType;
    links: LinksType;
    richTextResolver: RichTextResolver;
    resolveNestedRelations: boolean;
    private stringifiedStoriesCache;
    /**
     *
     * @param config ISbConfig interface
     * @param endpoint string, optional
     */
    constructor(config: ISbConfig, pEndpoint?: string);
    setComponentResolver(resolver: ComponentResolverFn): void;
    private parseParams;
    private factoryParamOptions;
    private makeRequest;
    get(slug: string, params?: ISbStoriesParams, fetchOptions?: ISbCustomFetch): Promise<ISbResult>;
    getAll(slug: string, params: ISbStoriesParams, entity?: string, fetchOptions?: ISbCustomFetch): Promise<any[]>;
    post(slug: string, params: ISbStoriesParams | ISbContentMangmntAPI, fetchOptions?: ISbCustomFetch): Promise<ISbResponseData>;
    put(slug: string, params: ISbStoriesParams | ISbContentMangmntAPI, fetchOptions?: ISbCustomFetch): Promise<ISbResponseData>;
    delete(slug: string, params: ISbStoriesParams | ISbContentMangmntAPI, fetchOptions?: ISbCustomFetch): Promise<ISbResponseData>;
    getStories(params: ISbStoriesParams, fetchOptions?: ISbCustomFetch): Promise<ISbStories>;
    getStory(slug: string, params: ISbStoryParams, fetchOptions?: ISbCustomFetch): Promise<ISbStory>;
    private getToken;
    ejectInterceptor(): void;
    private _cleanCopy;
    private _insertLinks;
    /**
     *
     * @param resolveId A counter number as a string
     * @param uuid The uuid of the story
     * @returns string | object
     */
    private getStoryReference;
    private _insertRelations;
    private iterateTree;
    private resolveLinks;
    private resolveRelations;
    /**
     *
     * @param responseData
     * @param params
     * @param resolveId
     * @description Resolves the relations and links of the stories
     * @returns Promise<void>
     *
     */
    private resolveStories;
    private cacheResponse;
    private throttledRequest;
    cacheVersions(): CachedVersions;
    cacheVersion(): number;
    setCacheVersion(cv: number): void;
    private cacheProvider;
    flushCache(): Promise<this>;
}
export default Storyblok;
